@@ -30,41 +30,10 @@
 G_BEGIN_DECLS
 
 
-#define GIMP_TYPE_COLOR_SCALE            (gimp_color_scale_get_type ())
-#define GIMP_COLOR_SCALE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_COLOR_SCALE, GimpColorScale))
-#define GIMP_COLOR_SCALE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_COLOR_SCALE, GimpColorScaleClass))
-#define GIMP_IS_COLOR_SCALE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_COLOR_SCALE))
-#define GIMP_IS_COLOR_SCALE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_COLOR_SCALE))
-#define GIMP_COLOR_SCALE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_COLOR_SCALE, GimpColorScaleClass))
+#define GIMP_TYPE_COLOR_SCALE (gimp_color_scale_get_type ())
+G_DECLARE_FINAL_TYPE (GimpColorScale, gimp_color_scale, GIMP, COLOR_SCALE, GtkScale)
 
 
-typedef struct _GimpColorScalePrivate GimpColorScalePrivate;
-typedef struct _GimpColorScaleClass   GimpColorScaleClass;
-
-struct _GimpColorScale
-{
-  GtkScale               parent_instance;
-
-  GimpColorScalePrivate *priv;
-};
-
-struct _GimpColorScaleClass
-{
-  GtkScaleClass  parent_class;
-
-  /* Padding for future expansion */
-  void (* _gimp_reserved1) (void);
-  void (* _gimp_reserved2) (void);
-  void (* _gimp_reserved3) (void);
-  void (* _gimp_reserved4) (void);
-  void (* _gimp_reserved5) (void);
-  void (* _gimp_reserved6) (void);
-  void (* _gimp_reserved7) (void);
-  void (* _gimp_reserved8) (void);
-};
-
-
-GType       gimp_color_scale_get_type         (void) G_GNUC_CONST;
 GtkWidget * gimp_color_scale_new              (GtkOrientation            orientation,
                                                GimpColorSelectorChannel  channel);
 
